"""
Default pricing data for AI models.
Used as fallback when live pricing fetch from GitHub fails.

Last updated: 2025-11-20T10:08:19+00:00
Source: https://raw.githubusercontent.com/cylestio/ai-model-pricing/main/latest.json
"""

DEFAULT_PRICING_DATA = {
    "last_updated": "2025-11-20T10:08:19+00:00",
    "models": {
        "anthropic": {
            "claude-sonnet-4-5-20250929": {"description": "Claude Sonnet 4.5", "input": 3.0, "output": 15.0},
            "claude-sonnet-4-5": {"description": "Claude Sonnet 4.5 (latest)", "input": 3.0, "output": 15.0},
            "claude-haiku-4-5-20251001": {"description": "Claude Haiku 4.5", "input": 1.0, "output": 5.0},
            "claude-haiku-4-5": {"description": "Claude Haiku 4.5 (latest)", "input": 1.0, "output": 5.0},
            "claude-opus-4-1-20250805": {"description": "Claude Opus 4.1", "input": 15.0, "output": 75.0},
            "claude-opus-4-1": {"description": "Claude Opus 4.1 (latest)", "input": 15.0, "output": 75.0},
            "claude-sonnet-4-20250514": {"description": "Claude Sonnet 4 (legacy)", "input": 3.0, "output": 15.0},
            "claude-sonnet-4-0": {"description": "Claude Sonnet 4 (legacy)", "input": 3.0, "output": 15.0},
            "claude-3-7-sonnet-20250219": {"description": "Claude Sonnet 3.7 (legacy)", "input": 3.0, "output": 15.0},
            "claude-3-7-sonnet-latest": {"description": "Claude Sonnet 3.7 (legacy)", "input": 3.0, "output": 15.0},
            "claude-opus-4-20250514": {"description": "Claude Opus 4 (legacy)", "input": 15.0, "output": 75.0},
            "claude-opus-4-0": {"description": "Claude Opus 4 (legacy)", "input": 15.0, "output": 75.0},
            "claude-3-5-haiku-20241022": {"description": "Claude Haiku 3.5 (legacy)", "input": 0.8, "output": 4.0},
            "claude-3-5-haiku-latest": {"description": "Claude Haiku 3.5 (legacy)", "input": 0.8, "output": 4.0},
            "claude-3-opus-20240229": {"description": "Claude Opus 3 (legacy)", "input": 15.0, "output": 75.0},
            "claude-3-haiku-20240307": {"description": "Claude Haiku 3 (legacy)", "input": 0.25, "output": 1.25},
        },
        "openai": {
            "gpt-5.1": {"description": "GPT-5.1", "input": 1.25, "output": 10.0},
            "gpt-5": {"description": "GPT-5", "input": 1.25, "output": 10.0},
            "gpt-5-mini": {"description": "GPT-5 Mini", "input": 0.25, "output": 2.0},
            "gpt-5-nano": {"description": "GPT-5 Nano", "input": 0.05, "output": 0.4},
            "gpt-5.1-chat-latest": {"description": "GPT-5.1 Chat (latest)", "input": 1.25, "output": 10.0},
            "gpt-5-chat-latest": {"description": "GPT-5 Chat (latest)", "input": 1.25, "output": 10.0},
            "gpt-5.1-codex": {"description": "GPT-5.1 Codex", "input": 1.25, "output": 10.0},
            "gpt-5-codex": {"description": "GPT-5 Codex", "input": 1.25, "output": 10.0},
            "gpt-5.1-codex-mini": {"description": "GPT-5.1 Codex Mini", "input": 0.25, "output": 2.0},
            "gpt-5-pro": {"description": "GPT-5 Pro", "input": 15.0, "output": 120.0},
            "gpt-5-search-api": {"description": "GPT-5 Search API", "input": 1.25, "output": 10.0},
            "gpt-4.1": {"description": "GPT-4.1", "input": 2.0, "output": 8.0},
            "gpt-4.1-mini": {"description": "GPT-4.1 Mini", "input": 0.4, "output": 1.6},
            "gpt-4.1-nano": {"description": "GPT-4.1 Nano", "input": 0.1, "output": 0.4},
            "gpt-4o": {"description": "GPT-4o", "input": 2.5, "output": 10.0},
            "gpt-4o-2024-05-13": {"description": "GPT-4o (2024-05-13)", "input": 5.0, "output": 15.0},
            "gpt-4o-2024-08-06": {"description": "GPT-4o (2024-08-06)", "input": 2.5, "output": 10.0},
            "gpt-4o-2024-11-20": {"description": "GPT-4o (2024-11-20)", "input": 2.5, "output": 10.0},
            "gpt-4o-mini": {"description": "GPT-4o Mini", "input": 0.15, "output": 0.6},
            "gpt-4o-mini-2024-07-18": {"description": "GPT-4o Mini (2024-07-18)", "input": 0.15, "output": 0.6},
            "gpt-4o-audio-preview": {"description": "GPT-4o Audio Preview", "input": 2.5, "output": 10.0},
            "gpt-4o-mini-audio-preview": {"description": "GPT-4o Mini Audio Preview", "input": 0.15, "output": 0.6},
            "gpt-4o-realtime-preview": {"description": "GPT-4o Realtime Preview", "input": 5.0, "output": 20.0},
            "gpt-4o-mini-realtime-preview": {"description": "GPT-4o Mini Realtime Preview", "input": 0.6, "output": 2.4},
            "gpt-4o-search-preview": {"description": "GPT-4o Search Preview", "input": 2.5, "output": 10.0},
            "gpt-4o-mini-search-preview": {"description": "GPT-4o Mini Search Preview", "input": 0.15, "output": 0.6},
            "gpt-realtime": {"description": "GPT Realtime", "input": 4.0, "output": 16.0},
            "gpt-realtime-mini": {"description": "GPT Realtime Mini", "input": 0.6, "output": 2.4},
            "gpt-audio": {"description": "GPT Audio", "input": 2.5, "output": 10.0},
            "gpt-audio-mini": {"description": "GPT Audio Mini", "input": 0.6, "output": 2.4},
            "gpt-image-1": {"description": "GPT Image 1", "input": 5.0, "output": 40.0},
            "gpt-image-1-mini": {"description": "GPT Image 1 Mini", "input": 2.0, "output": 8.0},
            "o1": {"description": "o1", "input": 15.0, "output": 60.0},
            "o1-pro": {"description": "o1 Pro", "input": 150.0, "output": 600.0},
            "o1-mini": {"description": "o1 Mini", "input": 1.1, "output": 4.4},
            "o1-mini-2024-09-12": {"description": "o1 Mini (2024-09-12)", "input": 1.1, "output": 4.4},
            "o1-preview": {"description": "o1 Preview", "input": 15.0, "output": 60.0},
            "o1-preview-2024-09-12": {"description": "o1 Preview (2024-09-12)", "input": 15.0, "output": 60.0},
            "o3": {"description": "o3", "input": 2.0, "output": 8.0},
            "o3-pro": {"description": "o3 Pro", "input": 20.0, "output": 80.0},
            "o3-mini": {"description": "o3 Mini", "input": 1.1, "output": 4.4},
            "o3-deep-research": {"description": "o3 Deep Research", "input": 10.0, "output": 40.0},
            "o4-mini": {"description": "o4 Mini", "input": 1.1, "output": 4.4},
            "o4-mini-deep-research": {"description": "o4 Mini Deep Research", "input": 2.0, "output": 8.0},
            "codex-mini-latest": {"description": "Codex Mini (latest)", "input": 1.5, "output": 6.0},
            "computer-use-preview": {"description": "Computer Use Preview", "input": 3.0, "output": 12.0},
            "chatgpt-4o-latest": {"description": "ChatGPT-4o (latest, legacy)", "input": 5.0, "output": 15.0},
            "gpt-3.5-turbo": {"description": "GPT-3.5 Turbo (legacy)", "input": 0.5, "output": 1.5},
            "gpt-3.5-turbo-0125": {"description": "GPT-3.5 Turbo 0125 (legacy)", "input": 0.5, "output": 1.5},
            "gpt-3.5-turbo-0613": {"description": "GPT-3.5 Turbo 0613 (legacy)", "input": 1.5, "output": 2.0},
            "gpt-3.5-turbo-1106": {"description": "GPT-3.5 Turbo 1106 (legacy)", "input": 1.0, "output": 2.0},
            "gpt-3.5-0301": {"description": "GPT-3.5 0301 (legacy)", "input": 1.5, "output": 2.0},
            "gpt-3.5-turbo-instruct": {"description": "GPT-3.5 Turbo Instruct (legacy)", "input": 1.5, "output": 2.0},
            "gpt-3.5-turbo-16k-0613": {"description": "GPT-3.5 Turbo 16K 0613 (legacy)", "input": 3.0, "output": 4.0},
            "gpt-4": {"description": "GPT-4 (legacy)", "input": 30.0, "output": 60.0},
            "gpt-4-0125-preview": {"description": "GPT-4 0125 Preview (legacy)", "input": 10.0, "output": 30.0},
            "gpt-4-0314": {"description": "GPT-4 0314 (legacy)", "input": 30.0, "output": 60.0},
            "gpt-4-0613": {"description": "GPT-4 0613 (legacy)", "input": 30.0, "output": 60.0},
            "gpt-4-1106-preview": {"description": "GPT-4 1106 Preview (legacy)", "input": 10.0, "output": 30.0},
            "gpt-4-1106-vision-preview": {"description": "GPT-4 Vision 1106 Preview (legacy)", "input": 10.0, "output": 30.0},
            "gpt-4-32k": {"description": "GPT-4 32K (legacy)", "input": 60.0, "output": 120.0},
            "gpt-4-turbo": {"description": "GPT-4 Turbo (legacy)", "input": 10.0, "output": 30.0},
            "gpt-4-turbo-2024-04-09": {"description": "GPT-4 Turbo 2024-04-09 (legacy)", "input": 10.0, "output": 30.0},
            "gpt-4-turbo-preview": {"description": "GPT-4 Turbo Preview (legacy)", "input": 10.0, "output": 30.0},
            "davinci-002": {"description": "Davinci-002 (legacy)", "input": 2.0, "output": 2.0},
            "babbage-002": {"description": "Babbage-002 (legacy)", "input": 0.4, "output": 0.4},
        },
    },
    "sources": {
        "anthropic": "https://claude.com/pricing#api",
        "openai": "https://platform.openai.com/docs/pricing",
    },
}

