// Theme and design tokens
export {
  theme,
  colors,
  typography,
  spacing,
  radii,
  shadows,
  transitions,
  breakpoints,
  zIndex,
  layout,
} from './theme';
export type { Theme } from './theme';

// Global styles
export { GlobalStyles } from './GlobalStyles';

// Animations
export * from './animations';
