export { SummaryStatsBar, type SummaryStatsBarProps } from './SummaryStatsBar';
export { SeverityProgressBar, type SeverityProgressBarProps } from './SeverityProgressBar';
export { IssueCard, type IssueCardProps } from './IssueCard';
export { CategoryDonut, type CategoryDonutProps } from './CategoryDonut';
export { SourceDistribution, type SourceDistributionProps } from './SourceDistribution';
export { DetectionTimeline, type DetectionTimelineProps } from './DetectionTimeline';

// Legacy export for backwards compatibility
export { FileTreemap, type FileTreemapProps } from './FileTreemap';
