export { RecommendationCard } from './RecommendationCard';
export type { RecommendationCardProps } from './RecommendationCard';

export { DismissModal } from './DismissModal';
export type { DismissModalProps, DismissType } from './DismissModal';

export { AuditTrail } from './AuditTrail';
export type { AuditTrailProps, AuditLogEntry } from './AuditTrail';

export { ProgressSummary } from './ProgressSummary';
export type { ProgressSummaryProps } from './ProgressSummary';

// Dashboard components
export * from './dashboard';
